@@ -1,9 +1,6 @@
-if ActiveRecord.gem_version >= Gem::Version.new('5.0')
-  class ActsAsTaggableOnMigration < ActiveRecord::Migration[4.2]; end
-else
-  class ActsAsTaggableOnMigration < ActiveRecord::Migration; end
-end
-ActsAsTaggableOnMigration.class_eval do
+# frozen_string_literal: true
+
+class ActsAsTaggableOnMigration < ActiveRecord::Migration[6.0]
   def self.up
     create_table ActsAsTaggableOn.tags_table do |t|
       t.string :name
@@ -25,8 +22,8 @@ ActsAsTaggableOnMigration.class_eval do
       t.datetime :created_at
     end
 
-    add_index ActsAsTaggableOn.taggings_table, :tag_id
-    add_index ActsAsTaggableOn.taggings_table, [:taggable_id, :taggable_type, :context], name: 'taggings_taggable_context_idx'
+    add_index ActsAsTaggableOn.taggings_table, %i[taggable_id taggable_type context],
+              name: 'taggings_taggable_context_idx'
   end
 
   def self.down
