@@ -1,16 +1,13 @@
-if ActiveRecord.gem_version >= Gem::Version.new('5.0')
-  class AddMissingUniqueIndices < ActiveRecord::Migration[4.2]; end
-else
-  class AddMissingUniqueIndices < ActiveRecord::Migration; end
-end
-AddMissingUniqueIndices.class_eval do
+# frozen_string_literal: true
+
+class AddMissingUniqueIndices < ActiveRecord::Migration[6.0]
   def self.up
     add_index ActsAsTaggableOn.tags_table, :name, unique: true
 
     remove_index ActsAsTaggableOn.taggings_table, :tag_id if index_exists?(ActsAsTaggableOn.taggings_table, :tag_id)
     remove_index ActsAsTaggableOn.taggings_table, name: 'taggings_taggable_context_idx'
     add_index ActsAsTaggableOn.taggings_table,
-              [:tag_id, :taggable_id, :taggable_type, :context, :tagger_id, :tagger_type],
+              %i[tag_id taggable_id taggable_type context tagger_id tagger_type],
               unique: true, name: 'taggings_idx'
   end
 
@@ -20,6 +17,7 @@ AddMissingUniqueIndices.class_eval do
     remove_index ActsAsTaggableOn.taggings_table, name: 'taggings_idx'
 
     add_index ActsAsTaggableOn.taggings_table, :tag_id unless index_exists?(ActsAsTaggableOn.taggings_table, :tag_id)
-    add_index ActsAsTaggableOn.taggings_table, [:taggable_id, :taggable_type, :context], name: 'taggings_taggable_context_idx'
+    add_index ActsAsTaggableOn.taggings_table, %i[taggable_id taggable_type context],
+              name: 'taggings_taggable_context_idx'
   end
 end
